/**
 * OS Management Hub API
 * Use the OS Management Hub API to manage and monitor updates and patches for the operating system environments in your private data centers through a single management console. For more information, see [Overview of OS Management Hub](https://docs.cloud.oracle.com/iaas/osmh/doc/overview.htm).
Use the table of contents and search tool to explore the  OS Management Hub API.

 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Detail information for an OCI Compute instance that is being managed.
 */
export interface ManagedInstance {
    /**
     * The OCID for the managed instance.
     */
    "id": string;
    /**
     * Managed instance identifier.
     */
    "displayName": string;
    /**
     * Information specified by the user about the managed instance.
     */
    "description"?: string;
    /**
     * The OCID for the tenancy this managed instance resides in.
     */
    "tenancyId": string;
    /**
     * The OCID for the compartment this managed instance resides in.
     */
    "compartmentId": string;
    /**
     * location of the managed instance.
     */
    "location"?: model.ManagedInstanceLocation;
    /**
     * Time at which the instance last checked in, as described in
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339), section 14.29.
     *
     */
    "timeLastCheckin"?: Date;
    /**
     * Time at which the instance last booted, as described in
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339), section 14.29.
     *
     */
    "timeLastBoot"?: Date;
    /**
     * Operating System Name.
     */
    "osName"?: string;
    /**
     * Operating System Version.
     */
    "osVersion"?: string;
    /**
     * Operating System Kernel Version.
     */
    "osKernelVersion"?: string;
    /**
     * The ksplice effective kernel version.
     */
    "kspliceEffectiveKernelVersion"?: string;
    /**
     * The CPU architecture type of the managed instance.
     */
    "architecture"?: model.ArchType;
    /**
     * The Operating System type of the managed instance.
     */
    "osFamily"?: model.OsFamily;
    /**
     * status of the managed instance.
     */
    "status": model.ManagedInstanceStatus;
    /**
     * The content profile of this instance.
     */
    "profile"?: string;
    /**
     * Whether this managed instance is acting as an on-premise management station.
     */
    "isManagementStation"?: boolean;
    /**
     * The OCID of a management station to be used as the preferred primary.
     */
    "primaryManagementStationId"?: string;
    /**
     * The OCID of a management station to be used as the preferred secondary.
     */
    "secondaryManagementStationId"?: string;
    /**
     * The list of software sources currently attached to the managed instance.
     */
    "softwareSources"?: Array<model.SoftwareSourceDetails>;
    "managedInstanceGroup"?: model.Id;
    "lifecycleEnvironment"?: model.Id;
    "lifecycleStage"?: model.Id;
    /**
     * Indicates whether a reboot is required to complete installation of updates.
     */
    "isRebootRequired"?: boolean;
    /**
     * Number of packages installed on the system. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "installedPackages"?: number;
    /**
     * Number of updates available to be installed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "updatesAvailable"?: number;
    /**
     * Number of security type updates available to be installed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "securityUpdatesAvailable"?: number;
    /**
     * Number of bug fix type updates available to be installed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "bugUpdatesAvailable"?: number;
    /**
     * Number of enhancement type updates available to be installed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "enhancementUpdatesAvailable"?: number;
    /**
     * Number of non-classified updates available to be installed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "otherUpdatesAvailable"?: number;
    /**
     * Number of scheduled jobs associated with this instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "scheduledJobCount"?: number;
    /**
     * Number of work requests associated with this instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "workRequestCount"?: number;
    /**
     * The date and time the work request was created, as described in
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339), section 14.29.
     *
     */
    "timeCreated"?: Date;
    /**
     * The date and time the work request was updated, as described in
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339), section 14.29.
     *
     */
    "timeUpdated"?: Date;
}
export declare namespace ManagedInstance {
    function getJsonObj(obj: ManagedInstance): object;
    function getDeserializedJsonObj(obj: ManagedInstance): object;
}
