/**
 * Network Monitoring API
 * Use the Network Monitoring API to troubleshoot routing and security issues for resources such as virtual cloud networks (VCNs) and compute instances. For more information, see the console
documentation for the [Network Path Analyzer](/iaas/Content/Network/Concepts/path_analyzer.htm) tool.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
export interface UpdateVirtualCircuitDetails {
    /**
     * The provisioned data rate of the connection. To get a list of the
     * available bandwidth levels (that is, shapes), see
     * {@link #listFastConnectProviderVirtualCircuitBandwidthShapes(ListFastConnectProviderVirtualCircuitBandwidthShapesRequest) listFastConnectProviderVirtualCircuitBandwidthShapes}.
     * To be updated only by the customer who owns the virtual circuit.
     *
     */
    "bandwidthShapeName"?: string;
    /**
      * An array of mappings, each containing properties for a cross-connect or
  * cross-connect group associated with this virtual circuit.
  * <p>
  The customer and provider can update different properties in the mapping
  * depending on the situation. See the description of the
  * {@link CrossConnectMapping}.
  *
      */
    "crossConnectMappings"?: Array<model.CrossConnectMapping>;
    /**
      * The BGP ASN of the network at the other end of the BGP
  * session from Oracle.
  * <p>
  If the BGP session is from the customer's edge router to Oracle, the
  * required value is the customer's ASN, and it can be updated only
  * by the customer.
  * <p>
  If the BGP session is from the provider's edge router to Oracle, the
  * required value is the provider's ASN, and it can be updated only
  * by the provider.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "customerBgpAsn"?: number;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
      * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the {@link Drg}
  * that this private virtual circuit uses.
  * <p>
  To be updated only by the customer who owns the virtual circuit.
  *
      */
    "gatewayId"?: string;
    /**
      * The provider's state in relation to this virtual circuit. Relevant only
  * if the customer is using FastConnect via a provider. ACTIVE
  * means the provider has provisioned the virtual circuit from their
  * end. INACTIVE means the provider has not yet provisioned the virtual
  * circuit, or has de-provisioned it.
  * <p>
  To be updated only by the provider.
  *
      */
    "providerState"?: UpdateVirtualCircuitDetails.ProviderState;
    /**
      * Provider-supplied reference information about this virtual circuit.
  * Relevant only if the customer is using FastConnect via a provider.
  * <p>
  To be updated only by the provider.
  *
      */
    "referenceComment"?: string;
}
export declare namespace UpdateVirtualCircuitDetails {
    enum ProviderState {
        Active = "ACTIVE",
        Inactive = "INACTIVE"
    }
    function getJsonObj(obj: UpdateVirtualCircuitDetails): object;
    function getDeserializedJsonObj(obj: UpdateVirtualCircuitDetails): object;
}
