/**
 * Application Dependency Management API
 * Use the Application Dependency Management API to create knowledge bases and vulnerability audits.  For more information, see [ADM](/Content/application-dependency-management/home.htm).
 * OpenAPI spec version: 20220421
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Vulnerability Audit summary.
 */
export interface VulnerabilityAuditSummary {
    /**
     * The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the Vulnerability Audit.
     */
    "id": string;
    /**
     * The name of the Vulnerability Audit.
     */
    "displayName"?: string;
    /**
     * The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
     */
    "knowledgeBaseId": string;
    /**
     * The creation date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
     */
    "timeCreated": Date;
    /**
     * The update date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
     */
    "timeUpdated": Date;
    /**
     * The current lifecycle state of the Vulnerability Audit.
     */
    "lifecycleState": string;
    /**
     * Maximum Common Vulnerability Scoring System Version 2 score observed for non-ignored vulnerable Application Dependencies. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxObservedCvssV2Score": number;
    /**
     * Maximum Common Vulnerability Scoring System Version 3 score observed for non-ignored vulnerable Application Dependencies. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxObservedCvssV3Score": number;
    /**
     * Count of non-ignored vulnerable Application Dependencies. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "vulnerableArtifactsCount": number;
    /**
     * Maximum Common Vulnerability Scoring System Version 2 score observed for vulnerable Application Dependencies including ignored ones. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxObservedCvssV2ScoreWithIgnored": number;
    /**
     * Maximum Common Vulnerability Scoring System Version 3 score observed for vulnerable Application Dependencies including ignored ones. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxObservedCvssV3ScoreWithIgnored": number;
    /**
     * Count of all vulnerable Application Dependencies. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "vulnerableArtifactsCountWithIgnored": number;
    /**
     * Indicates if an audit succeeded according to the configuration. The value is `null` if the audit is in the `CREATING` state.
     */
    "isSuccess"?: boolean;
    /**
     * Type of the build tool.
     */
    "buildType"?: string;
    /**
     * The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.
     */
    "compartmentId": string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: `{\"bar-key\": \"value\"}`
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Usage of system tag keys. These predefined keys are scoped to namespaces.
     * Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace VulnerabilityAuditSummary {
    function getJsonObj(obj: VulnerabilityAuditSummary): object;
    function getDeserializedJsonObj(obj: VulnerabilityAuditSummary): object;
}
